define(["exports", "core/pubsubhub"], function (exports, _pubsubhub) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.name = undefined;
  exports.run = run;
  // Module core/dfn
  // Finds all <dfn> elements and populates conf.definitionMap to identify them.
  const name = exports.name = "core/dfn";

  function canonicalize(query, attributeName) {
    const offendingElements = document.querySelectorAll(query);
    const offendingMsg = "The `for` and `dfn-for` attributes are deprecated. " + "Please use `data-dfn-for` instead. See developer console.";
    if (offendingElements.length) {
      (0, _pubsubhub.pub)(offendingMsg);
    }
    Array.from(offendingElements).forEach(el => {
      console.warn(offendingMsg, el);
      el.dataset.dfnFor = el.getAttribute(attributeName).toLowerCase();
      el.removeAttribute(attributeName);
    });
  }

  function run(conf, doc, cb) {
    if (!conf.hasOwnProperty("definitionMap")) {
      conf.definitionMap = Object.create(null);
    }
    // Canonicalize "dfn-for" and "for" attributes to data-dfn-for
    canonicalize("[dfn-for]", "dfn-for");
    canonicalize("dfn[for]", "for");
    Array.from(document.querySelectorAll("dfn")).forEach(dfn => {
      const closestDfn = dfn.closest("[data-dfn-for]");
      if (closestDfn && closestDfn !== dfn && !dfn.dataset.dfnFor) {
        dfn.dataset.dfnFor = closestDfn.dataset.dfnFor;
      }
      if (dfn.dataset.dfnFor) {
        dfn.dataset.dfnFor = dfn.dataset.dfnFor.toLowerCase();
      }
      // TODO: dfn's are tragically jquery'ed and stored. Should fix this.
      // Also, we should probably use weakmaps and weaksets here
      // to avoid leaks.
      const $dfn = $(dfn);
      $dfn.getDfnTitles({ isDefinition: true }).map(dfnTitle => {
        if (!conf.definitionMap[dfnTitle]) {
          conf.definitionMap[dfnTitle] = [];
        }
        return conf.definitionMap[dfnTitle];
      }).reduce(function ($dfn, dfnTitleContainer) {
        dfnTitleContainer.push($dfn);
        return $dfn;
      }, $dfn);
    });
    cb();
  }
});
//# sourceMappingURL=dfn.js.map